import React from 'react';

/**
 * React component to highlight specified words in a string of text. Highlight styling is applied
 * via the `renderHighlight` render prop.
 */

var Highlighter = function Highlighter(_ref) {
  var children = _ref.children,
      searchTerm = _ref.searchTerm,
      _ref$renderHighlight = _ref.renderHighlight,
      renderHighlight = _ref$renderHighlight === void 0 ? function (word, idx) {
    return React.createElement("strong", {
      key: idx
    }, word);
  } : _ref$renderHighlight;
  if (typeof children !== 'string') throw new Error('<Highlighter> children must be a string!');
  var searchExp = searchTerm instanceof RegExp ? searchTerm : new RegExp(searchTerm, 'ig');
  var searchResult = children.match(searchExp);
  if (!searchResult) return React.createElement(React.Fragment, null, "children");
  var splitWords = children.split(searchExp).reduce(function (acc, curr, idx, arr) {
    acc.push(curr);
    if (idx < arr.length - 1) acc.push(renderHighlight(searchResult[idx], idx));
    return acc;
  }, []);
  return React.createElement(React.Fragment, null, splitWords);
};

export { Highlighter };
//# sourceMappingURL=highlighter.esm.js.map
